@@ -16,7 +16,7 @@ class BroadRunner:
     """
     def __init__(self, picard_ref, gatk_dir, config):
         resources = config_utils.get_resources("gatk", config)
-        self._jvm_opts = resources.get("jvm_opts", ["-Xmx6g", "-Xms6g"])
+        self._jvm_opts = resources.get("jvm_opts", ["-Xms750m", "-Xmx2g"])
         self._picard_ref = picard_ref
         self._gatk_dir = gatk_dir or picard_ref
         self._config = config
@@ -81,6 +81,7 @@ class BroadRunner:
                 params.extend(["-nct", str(cores)])
         if len([x for x in params if x.startswith(("-U", "--unsafe"))]) == 0:
             params.extend(["-U", "LENIENT_VCF_PROCESSING"])
+        params.extend(["--read_filter", "BadCigar", "--read_filter", "NotPrimaryAlignment"])
         local_args.append("-Djava.io.tmpdir=%s" % tmp_dir)
         return ["java"] + self._jvm_opts + local_args + \
           ["-jar", gatk_jar] + [str(x) for x in params]
@@ -98,14 +99,14 @@ class BroadRunner:
         the latest 2.4+ restricted version of GATK.
         """
         gatk_jar = self._get_jar("GenomeAnalysisTK", ["GenomeAnalysisTKLite"])
-        cl = ["java", "-jar", gatk_jar, "-version"]
+        cl = ["java"] + self._jvm_opts + ["-jar", gatk_jar, "-version"]
         with closing(subprocess.Popen(cl, stdout=subprocess.PIPE, stderr=subprocess.STDOUT).stdout) as stdout:
             out = stdout.read().strip()
-            # version was not properly implemented in earlier versions
-            if out.find("USER ERROR") > 0:
-                version = 2.3
-            else:
+            try:
                 version, subversion, githash = out.split("-")
+            # version was not properly implemented in earlier versions
+            except ValueError:
+                version = 2.3
             if float(version) > 2.3:
                 return "restricted"
             else:
