@@ -39,7 +39,7 @@ def cpmap(cores=1):
         IMapIterator.next = wrapper(IMapIterator.next)
         # recycle threads on Python 2.7; remain compatible with Python 2.6
         try:
-            pool = multiprocessing.Pool(int(cores), maxtasksperchild=1)
+            pool = multiprocessing.pool(int(cores), maxtasksperchild=None)
         except TypeError:
             pool = multiprocessing.Pool(int(cores))
         yield pool.imap_unordered
