@@ -45,6 +45,8 @@ def _shared_gatk_call_prep(align_bams, ref_file, config, dbsnp, region, out_file
     params = ["-R", ref_file,
               "--standard_min_confidence_threshold_for_calling", confidence,
               "--standard_min_confidence_threshold_for_emitting", confidence,
+              "--downsample_to_coverage", "250",
+              "--downsampling_type", "BY_SAMPLE",
               ]
     for a in annotation.get_gatk_annotations(config):
         params += ["--annotation", a]
@@ -344,11 +346,11 @@ def _variant_filtration_both(broad_runner, snp_file, ref_file, vrn_files,
 
 # ## Variant evaluation
 
-def gatk_evaluate_variants(vcf_file, ref_file, config, dbsnp=None, intervals=None):
+def gatk_evaluate_variants(vcf_file, ref_file, config, dbsnp=None):
     """Evaluate variants, return SNP counts and Transition/Transversion ratios.
     """
     runner = broad.runner_from_config(config)
-    eval_file = variant_eval(vcf_file, ref_file, dbsnp, intervals, runner)
+    eval_file = variant_eval(vcf_file, ref_file, dbsnp, runner)
     stats = _extract_eval_stats(eval_file)
     return _format_stats(stats['called'])
 
@@ -417,7 +419,7 @@ def _eval_analysis_type(in_file, analysis_name):
             parts = line.rstrip("\n\r").split()
             yield parts
 
-def variant_eval(vcf_in, ref_file, dbsnp, target_intervals, picard):
+def variant_eval(vcf_in, ref_file, dbsnp, picard):
     """Evaluate variants in comparison with dbSNP reference.
     """
     out_file = "%s.eval" % os.path.splitext(vcf_in)[0]
@@ -426,6 +428,7 @@ def variant_eval(vcf_in, ref_file, dbsnp, target_intervals, picard):
             params = ["-T", "VariantEval",
                       "-R", ref_file,
                       "--eval", vcf_in,
+                      "-L", vcf_in,
                       "--dbsnp", dbsnp,
                       "-ST", "Filter",
                       "-o", tx_out_file,
@@ -436,15 +439,6 @@ def variant_eval(vcf_in, ref_file, dbsnp, target_intervals, picard):
                       "--evalModule", "TiTvVariantEvaluator",
                       "--evalModule", "ValidationReport",
                       "--stratificationModule", "Filter"]
-            if target_intervals:
-                # BED file target intervals are explicit with GATK 1.3
-                # http://getsatisfaction.com/gsa/topics/
-                # gatk_v1_3_and_bed_interval_file_must_be_parsed_through_tribble
-                if _is_bed_file(target_intervals):
-                    flag = "-L:bed"
-                else:
-                    flag = "-L"
-                params.extend([flag, target_intervals])
             picard.run_gatk(params)
     return out_file
 
@@ -500,6 +494,8 @@ def handle_multiple_variantcallers(data):
     callers = get_variantcaller(data[0])
     if isinstance(callers, basestring):
         return [data]
+    elif not callers:
+        return []
     else:
         out = []
         for caller in callers:
@@ -541,24 +537,22 @@ def variantcall_sample(data, region=None, out_file=None):
                   "cortex": cortex.run_cortex,
                   "samtools": samtools.run_samtools,
                   "varscan": varscan.run_varscan}
-    if data["config"]["algorithm"]["snpcall"]:
-        sam_ref = data["sam_ref"]
-        config = data["config"]
-        caller_fn = caller_fns[config["algorithm"].get("variantcaller", "gatk")]
-        if isinstance(data["work_bam"], basestring):
-            align_bams = [data["work_bam"]]
-        else:
-            align_bams = data["work_bam"]
-        call_vcf = caller_fn(align_bams, sam_ref, config,
-                             configured_ref_file("dbsnp", config, sam_ref),
-                             region, out_file)
-        if data["config"]["algorithm"].get("phasing", "gatk") == "gatk":
-            call_vcf = phasing.read_backed_phasing(call_vcf, align_bams, sam_ref, region, config)
-        if call_vcf != out_file:
-            for ext in ["", ".idx"]:
-                if os.path.exists(call_vcf + ext):
-                    shutil.move(call_vcf + ext, out_file + ext)
-            with open(call_vcf, "w") as out_handle:
-                out_handle.write("Moved to %s" % out_file)
-        data["vrn_file"] = out_file
+    sam_ref = data["sam_ref"]
+    config = data["config"]
+    caller_fn = caller_fns[config["algorithm"].get("variantcaller", "gatk")]
+    if isinstance(data["work_bam"], basestring):
+        align_bams = [data["work_bam"]]
+    else:
+        align_bams = data["work_bam"]
+    call_file = "%s-raw%s" % os.path.splitext(out_file)
+    caller_fn(align_bams, sam_ref, config,
+              configured_ref_file("dbsnp", config, sam_ref),
+              region, call_file)
+    if data["config"]["algorithm"].get("phasing", False) == "gatk":
+        call_file = phasing.read_backed_phasing(call_file, align_bams, sam_ref, region, config)
+    if not os.path.exists(out_file):
+        for ext in ["", ".idx"]:
+            if os.path.exists(call_file + ext):
+                os.symlink(call_file + ext, out_file + ext)
+    data["vrn_file"] = out_file
     return [data]
